var uni = /** @class */ (function () {
    function uni() {
    }
    uni._init = function () {
        uni.urlVars = uni.getURLVariables();
        if (uni.urlVars["uni_debug"] == "1") {
            uni.apiHost = uni.apiHost_debug;
        }
        //检查平台
        if (uni.urlVars["sign"] != undefined && uni.urlVars["gameId"] != undefined) {
            //4399开放平台
            uni.plat = UniPlat.OPEN43;
        }
        else {
            //桌趣
            uni.plat = UniPlat.ZQ;
            Impl._init();
        }
    };
    uni.init = function (AppID, gameType, open43GameID, onInitedCallback) {
        if (open43GameID === void 0) { open43GameID = 0; }
        if (onInitedCallback === void 0) { onInitedCallback = null; }
        uni.AppId = AppID;
        uni.inited = true;
        if (gameType != 1 && gameType != 2 && gameType != 3) {
            gameType = 3;
        }
        uni.gameType = gameType;
        if (uni.plat == UniPlat.ZQ) {
            Impl.startup();
        }
        else if (uni.plat == UniPlat.OPEN43) {
            Open4399Impl.startup();
        }
        uni.ADInitCallback = onInitedCallback;
        if (open43GameID != 0) {
            uni.initAD(open43GameID);
        }
    };
    /**
     * 执行登录
     * @param {Object} object {
     *  success:成功回调({userInfo:Object}),
     *  fail:失败回调({code, message}=>any),
     *  complete:成功以及失败都会执行的回调,
     *  timeout:超时时间(ms)，默认5000ms,
     *  debug_scookie:用于调试的scookie,
     *  debug_uid:用于调试的uid
     *  }
     */
    uni.login = function (object) {
        if (!uni.inited) {
            throw "还未调用init()函数进行初始化";
        }
        if (uni.plat == UniPlat.OPEN43) {
            if (!Open4399Impl.APIRefCreated) {
                Open4399Impl.markWaitToLogin(object);
                return;
            }
        }
        var succCallback = object["success"];
        var failCallback = object["fail"];
        var completeCallback = object["complete"];
        var req = new XMLHttpRequest();
        req.timeout = object["timeout"] || 5000;
        req.ontimeout = function () {
            if (failCallback != null) {
                failCallback({ code: req.status, message: "time out" });
            }
            if (completeCallback != null) {
                completeCallback();
            }
        };
        req.onerror = function (ev) {
            console.log(req.status, ev.message);
            if (failCallback != null) {
                failCallback({ code: req.status, message: ev.message });
            }
            if (completeCallback != null) {
                completeCallback();
            }
        };
        req.onload = function () {
            console.log(req.responseText);
            var data = {};
            try {
                data = JSON.parse(req.responseText);
            }
            catch (e) {
                data["code"] = 10008;
                data["message"] = req.responseText;
            }
            if (data["code"] == 10000) {
                uni.logined = true;
                //记录token，准备后续接口使用
                uni.token = data["data"]["token"];
                uni.uid = data["data"]["userInfo"]["uid"];
                uni.nickName = data["data"]["userInfo"]["nickName"];
                uni.gameName = data["data"]["gameName"];
                if (uni.plat == UniPlat.OPEN43) {
                    data["data"]["userInfo"]["avatar"] = Open4399Impl.getUserAvatar(uni.uid.toString());
                }
                if (succCallback != null) {
                    succCallback(data["data"]);
                }
                if (uni.gameType == UniGameType.SINGLE_PLAYER) {
                    uni.heartbeat();
                }
            }
            else {
                if (failCallback != null) {
                    failCallback({ code: data["code"], message: data["message"] });
                }
            }
            if (completeCallback != null) {
                completeCallback();
            }
        };
        if (uni.plat == UniPlat.ZQ) {
            Impl.loginInPlatform(req, object["debug_scookie"], object["debug_uid"]);
        }
        else if (uni.plat == UniPlat.OPEN43) {
            Open4399Impl.loginInPlatform(req);
        }
    };
    /**
     * 游戏程序准备完毕可开始玩时调用此接口，用于数据统计
     * @param {Object} object {success:成功回调()=>any, fail:失败回调(code:Number, message:String)=>any, complete:成功以及失败都会执行的回调()=>any}
     */
    uni.standby = function (object) {
        if (object === void 0) { object = null; }
        this.checkLogin();
        if (uni.gameType == UniGameType.SINGLE_PLAYER) {
            var req = uni.createStandardRequest(object);
            req.open("GET", uni.getServerAPI("gameLogin"));
            req.send();
        }
        else {
            if (object["success"] != undefined) {
                object["success"]();
            }
            if (object["complete"] != undefined) {
                object["complete"]();
            }
        }
        if (uni.plat == UniPlat.ZQ) {
            Impl.standby();
        }
    };
    /**
     * 游戏开始或者重玩时必须调用此接口，标记游戏已经开始，用于数据统计
     * @param {Object} object {success:成功回调()=>any, fail:失败回调(code:Number, message:String)=>any, complete:成功以及失败都会执行的回调()=>any, level:难度等级，若游戏不分难度等级则不传此参数，与getWeekRanking()和getMonthRanking()函数的level参数对应}
     */
    uni.gameStart = function (object) {
        if (object === void 0) { object = null; }
        if (uni.gameType == UniGameType.SINGLE_PLAYER) {
            this.checkLogin();
            /*if(uni.gameStarted){
                return;
            }*/
            var req = uni.createStandardRequest(object);
            var level = 1;
            if (object != null && object["level"] != undefined && object["level"] > 0) {
                level = object["level"];
            }
            req.open("GET", uni.getServerAPI("gameBegin") + "&level=" + level);
            req.send();
            //uni.gameStarted = true;
        }
    };
    /**
     * 标记本局游戏已经结束，并提交游戏积分
     * @param {Object} object {score:number(得分), fpsAVG:number(游戏平均帧频，可选), success:成功回调, fail:失败回调({code, message}=>any), complete:成功以及失败都会执行的回调}
     */
    uni.gameFinish = function (object) {
        if (uni.gameType == UniGameType.SINGLE_PLAYER) {
            this.checkLogin();
            var url = uni.getServerAPI("gameFinish");
            url = uni.addURLParamFromObj(url, object, "score", 0);
            url = uni.addURLParamFromObj(url, object, "fpsAVG", 60, "frameNum");
            var req_1 = uni.createStandardRequest(object);
            req_1.onload = function () {
                console.log(req_1.responseText);
            };
            req_1.open("GET", url);
            req_1.send();
        }
    };
    /**
     * 获取周排行榜数据
     * @param {Object} object {pageSize, pageNO, success, fail, complete, level}
     */
    uni.getWeekRanking = function (object) {
        this.checkLogin();
        uni.getRanking(object, uni.AppId + "WR");
    };
    /**
     * 获取月排行榜
     * @param {Object} object {pageSize, pageNO, success, fail, complete, level}
     */
    uni.getMonthRanking = function (object) {
        this.checkLogin();
        uni.getRanking(object, uni.AppId + "MR");
    };
    uni.getRanking = function (object, rankingName) {
        uni.checkParam(object, "pageSize");
        uni.checkParam(object, "pageNO");
        var pageSize = object["pageSize"];
        var pageNO = object["pageNO"];
        var level = object["level"];
        if (isNaN(level) || level < 1) {
            level = 1;
        }
        rankingName = rankingName + "_" + level;
        var req = uni.createStandardRequest(object);
        req.open("GET", uni.getServerAPI("getRanking") + "&rankname=" + rankingName + "&shownum=" + pageSize + "&page=" + pageNO);
        req.send();
    };
    /**
     * 获取服务器当前时间戳（单位：毫秒，视网络情况，有一定误差）
     * @param {Object} object {success:成功回调(timestamp:number)=>any, fail:失败回调(code:Number, message:String)=>any, complete:成功以及失败都会执行的回调()=>any}
     */
    uni.getServerTimestamp = function (object) {
        var success = object["success"];
        delete object["success"];
        var req = uni.createStandardRequest(object);
        var time = Date.now();
        req.onload = function () {
            var obj = JSON.parse(req.responseText);
            if (success != undefined) {
                success(obj["data"]["timestamp"] * 1000 + (Date.now() - time) / 2);
            }
        };
        req.open("GET", uni.getServerAPI("gameHeartbeat"));
        req.send();
    };
    //->app相关接口//////////////////////////////////
    /**
     * 退出游戏到app
     */
    uni.exit = function () {
        if (uni.plat == UniPlat.ZQ) {
            Impl.exit();
        }
        else {
            console.log("当前平台不支持exit()");
        }
    };
    /**
     * 邀请app好友加入当前游戏
     * @param {Object} object<br>
     *     {any} parameters 一个自定义的任意类型参数（如果是object或者array，在传递过程中会被转换为json），此参数与onStartGameWithInvitation注册的回调函数的parameters参数对应
     */
    uni.inviteToGame = function (object) {
        //parameters:any = null, multiple:boolean = false
        this.checkLogin();
        if (uni.plat == UniPlat.ZQ) {
            Impl.invite(object["parameters"]);
        }
        else if (uni.plat == UniPlat.OPEN43) {
            Open4399Impl.invite(object["parameters"]);
            Api.onSendInviteSuccess("", "");
        }
    };
    /**
     * 注册将"邀请加入游戏"的消息发送到app内好友后的回调（如果邀请多人，则回调会被执行多次）
     * @param {(targetUID:string, targetName:string) => any} callback
     */
    uni.onSendGameInvite = function (callback) {
        Api.inviteSendSuccessCallback = callback;
    };
    /**
     * 邀请 QQ/微信 好友加入当前游戏
     * @param {Object} object<br>
     *     {any} parameters 一个自定义的任意类型参数（如果是object或者array，在传递过程中会被转换为json），此参数与onStartGameWithInvitation注册的回调函数的parameters参数对应
     *     {(platType:string) => any} success 邀请发送成功的回调，platType参数：0 微信，1 QQ， 2 微博
     *     {() => any} fail 邀请发送失败的回调
     */
    uni.inviteFromSociety = function (object) {
        this.checkLogin();
        if (uni.plat == UniPlat.ZQ) {
            Impl.setShareCallback(object["success"], object["fail"]);
            Impl.inviteFromSociety(object["parameters"]);
        }
        else if (uni.plat == UniPlat.OPEN43) {
            Open4399Impl.inviteFromSociety(object["parameters"]);
            if (object["success"] != undefined) {
                object["success"]("");
            }
        }
    };
    /**
     * 注册app内好友点击拒绝"邀请加入游戏"后的回调（有几个人拒绝，就有几次回调）
     * @param {(targetUID:string, targetName:string) => any} callback
     */
    uni.onInviteRefused = function (callback) {
        Api.inviteRefusedCallback = callback;
    };
    /**
     * 注册"检查当前是否可以被邀请"时的回调函数
     * @param {()=>boolean} callback 回调函数，表示当前是否可被邀请，可被邀请返回true，不可被邀请返回false。未注册有效函数则默认为可被邀请
     */
    uni.onInviteableCheck = function (callback) {
        uni.inviteableCheckCallback = callback;
    };
    /**
     * 注册app中点击创建房间的方式开始游戏的回调函数
     * @param {() => any} callback
     */
    uni.onWillToCreateGameRoom = function (callback) {
        uni.createGameRoomCallback = callback;
    };
    /**
     * 注册当通过被邀请进入游戏时的回调函数
     * @param {(obj:Object) => any} callback 回调函数的obj包含一下属性：
     *      uid:string 邀请人的uid
     *      nickName:string 邀请人的昵称
     *      parameters:any 发送邀请时携带的参数
     */
    uni.onStartGameWithInvitation = function (callback) {
        uni.startGameWithInvitationCallback = callback;
    };
    /**
     * APP进入后台后回调方法
     * callback:进入后台的回调
     */
    uni.onEnterBackground = function (callback) {
        Api.didEnterBackgroundCallback = callback;
    };
    /**
     * 切回app回调方法
     * callback:切回app的回调
     */
    uni.onEnterForeground = function (callback) {
        Api.willEnterForegroundCallback = callback;
    };
    /**
     * 查看玩家信息
     * @param {string} uid 要查看的玩家的uid
     */
    uni.viewProfile = function (uid) {
        if (uni.plat == UniPlat.ZQ) {
            Impl.callGameAPI("goPlayerHome", uid);
        }
        else {
            Open4399Impl.viewUserProfile(uid);
        }
    };
    /**
     * 打开意见反馈界面
     */
    uni.feedback = function () {
        if (uni.plat == UniPlat.ZQ) {
            Impl.callGameAPI("openFeedBack", uni.AppId);
        }
        else {
            console.log("当前平台不支持意见反馈");
        }
    };
    /**
     * 调用社会化分享接口
     * @param {Object} object<br>
     *     {any} parameters 一个自定义的任意类型参数（如果是object或者array，在传递过程中会被转换为json），此参数与onStartGameWithInvitation注册的回调函数的parameters参数对应
     *     {(platType:string) => any} success 邀请发送成功的回调，platType参数：0 微信，1 QQ， 2 微博
     *     {() => any} fail 邀请发送失败的回调
     */
    uni.shareToSociety = function (object) {
        this.checkLogin();
        if (uni.plat == UniPlat.ZQ) {
            Impl.setShareCallback(object["success"], object["fail"]);
            Impl.inviteFromSociety(object["parameters"]);
        }
        else if (uni.plat == UniPlat.OPEN43) {
            Open4399Impl.inviteFromSociety(object["parameters"]);
            if (object["success"] != undefined) {
                object["success"]("");
            }
        }
    };
    /**
     * 客户端js 代码已经OK用于 一般一开始有舞台就要调用
     */
    uni.onJsLoadComplete = function () {
        Impl.callGameAPI("onJsLoadComplete");
    };
    //分享对战结果
    uni.shareVSResult = function () {
    };
    /**
     * 用户数据存档
     * @param {Object} object {data:string, idx:number = 0, success:成功回调((res:Object) => any), fail:失败回调((code, message)=>any), complete:(() => any)成功以及失败都会执行的回调}<br>
     *     success函数的res参数：{idx:number}
     */
    uni.archiveProfile = function (object) {
        var req = uni.createStandardRequest(object);
        var idx = object["idx"] || 0;
        var form = new FormData();
        form.append("flag", uni.AppId);
        form.append("token", uni.token);
        form.append("idx", idx);
        form.append("data", object["data"]);
        req.open("POST", uni.getServerAPI("gameSave", false));
        req.send(form);
    };
    /**
     * 分享积分排行榜
     * @param {Object} object<br>
     *     {(platType:string) => any} success 邀请发送成功的回调，platType参数：0 微信，1 QQ， 2 微博
     *     {() => any} fail 邀请发送失败的回调
     */
    uni.shareScore = function (object) {
        if (uni.plat == UniPlat.ZQ) {
            //获取排行榜数据
            this.checkLogin();
            var url = uni.getServerAPI("flauntRanking");
            url += "&rankname=" + uni.AppId + "WR";
            var req_2 = uni.createStandardRequest();
            req_2.onload = function () {
                var rankList = JSON.parse(req_2.responseText)["data"]["rankList"];
                for (var i = 0; i < rankList.length; i++) {
                    var item = rankList[i];
                    item["userName"] = item["nickName"];
                    item["sex"] = item["gender"];
                    delete item["nickName"];
                    delete item["gender"];
                }
                var obj = {
                    uid: uni.uid,
                    gameName: uni.gameName,
                    flag: uni.AppId,
                    rankList: rankList
                };
                Impl.setShareCallback(object["success"], object["fail"]);
                var shareString = JSON.stringify(obj);
                console.log(shareString);
                Impl.callGameAPI("shareGameFinishInfo", shareString, uni.gameType);
            };
            req_2.open("GET", url);
            req_2.send();
        }
        else {
            console.log("当前平台不支持此分享");
        }
    };
    /**
     * 读取当前用户的存档
     * @param {Object} object {idx:number = 0 success:成功回调((res:Object) => any), fail:失败回调((code, message)=>any), complete:(() => any)成功以及失败都会执行的回调}<br>
     *     success函数的res参数：{idx:number, data:Unit8Array}
     */
    uni.getArchivedProfile = function (object) {
        var req = uni.createStandardRequest(object);
        var idx = object["idx"] || 0;
        req.open("GET", uni.getServerAPI("gameGetSave") + "&idx=" + idx);
        req.send();
    };
    uni.heartbeat = function () {
        if (uni.heartbeatTimeoutID != 0) {
            clearTimeout(uni.heartbeatTimeoutID);
        }
        if (uni.heartbeatReq == null) {
            uni.heartbeatReq = new XMLHttpRequest();
        }
        uni.heartbeatReq.onload = function () {
            var obj = JSON.parse(uni.heartbeatReq.responseText);
            uni.syncedServerTime = obj["data"]["timestamp"] * 1000;
            uni.syncedLocalTime = Date.now();
            uni.token = obj["data"]["token"];
            console.log("new token:" + uni.token);
        };
        uni.heartbeatReq.open("GET", uni.getServerAPI("gameHeartbeat"));
        uni.heartbeatReq.send();
        //5分钟发送一次心跳
        uni.heartbeatTimeoutID = setTimeout(uni.heartbeat, 1000 * 60 * 1);
    };
    uni.getServerAPI = function (apiName, withAuth) {
        if (withAuth === void 0) { withAuth = true; }
        return uni.apiHost + apiName + (withAuth ? ("?flag=" + uni.AppId + "&token=" + uni.token) : "");
    };
    uni.createStandardRequest = function (callbacks) {
        if (callbacks === void 0) { callbacks = null; }
        var req = new XMLHttpRequest();
        if (callbacks != null) {
            if (callbacks["success"] != null || callbacks["complete"] != null) {
                req.addEventListener("load", function (ev) {
                    var json = req.responseText;
                    var obj = {};
                    try {
                        obj = JSON.parse(json);
                    }
                    catch (e) {
                        obj["code"] = 10008;
                        obj["message"] = json;
                    }
                    if (obj["code"] == 10000) {
                        if (callbacks["success"] != null) {
                            callbacks["success"](obj["data"]);
                        }
                    }
                    else {
                        console.log(req.responseText);
                        if (callbacks["fail"] != null) {
                            callbacks["fail"](obj);
                        }
                    }
                    if (callbacks["complete"] != null) {
                        callbacks["complete"](obj);
                    }
                });
            }
            if (callbacks["fail"] != null || callbacks["complete"] != null) {
                req.addEventListener("error", function (ev) {
                    var obj = {};
                    obj["code"] = 10007;
                    obj["message"] = ev.message;
                    if (callbacks["fail"] != null) {
                        callbacks["fail"](obj);
                    }
                    if (callbacks["complete"] != null) {
                        callbacks["complete"](obj);
                    }
                });
            }
        }
        return req;
    };
    uni.checkLogin = function () {
        if (!this.logined) {
            throw "未登录，不可执行后续操作";
        }
    };
    //->工具函数/////////////////////////////
    /**
     * 获取url参数
     * @returns {object}
     */
    uni.getURLVariables = function () {
        var url = location.search; //获取url中"?"符后的字串
        var vars = {};
        if (url.indexOf("?") != -1) {
            var str = url.substr(1);
            var strs = str.split("&");
            for (var i = 0; i < strs.length; i++) {
                vars[strs[i].split("=")[0]] = (strs[i].split("=")[1]);
            }
        }
        return vars;
    };
    uni.checkParam = function (object, paName) {
        if (object == null || object[paName] == undefined) {
            throw "属性" + paName + "为必填项";
        }
    };
    uni.addURLParamFromObj = function (url, obj, propName, defaultValue, paramName) {
        if (defaultValue === void 0) { defaultValue = undefined; }
        if (paramName === void 0) { paramName = null; }
        if (paramName == null) {
            paramName = propName;
        }
        var value = obj[propName] || defaultValue;
        if (value != undefined) {
            var joinChar = url.indexOf("?") == -1 ? "?" : "&";
            url += joinChar + paramName + "=" + value;
        }
        return url;
    };
    /**
     * 加入语音聊天频道
     * @param {string} id 频道id，加入相同id频道的用户语音互通
     */
    uni.joinChannel = function (id) {
        if (id != null && id != uni.joinedChannelId) {
            uni.leaveChannel();
            uni.joinedChannelId = id;
            Impl.callVoiceAPI("joinChannel", uni.AppId + "_" + id);
        }
    };
    /**
     * 离开当前的语音聊天频道，在停止语音聊天时必须调用此方法
     */
    uni.leaveChannel = function () {
        if (uni.joinedChannelId != null) {
            uni.joinedChannelId = null;
            Impl.callVoiceAPI("leaveChannel");
        }
    };
    /**
     * 切换当前用户的静音情况
     * @param {boolean} mute 是否静音，值为true时，房间内其他人听不到当前用户的语音
     */
    uni.muteSelf = function (mute) {
        if (mute) {
            Impl.callVoiceAPI("openMute");
        }
        else {
            Impl.callVoiceAPI("closeMute");
        }
    };
    /**
     * 切换房间内其他人的静音情况
     * @param {boolean} mute 是否静音，值为true时，当前用户听不到房间内其他用户的语音
     */
    uni.muteOthers = function (mute) {
        if (mute) {
            Impl.callVoiceAPI("openMuteAllRemoteAudio");
        }
        else {
            Impl.callVoiceAPI("closeMuteAllRemoteAudio");
        }
    };
    /**
     * 释放语音聊天功能
     */
    uni.releaseVoiceChat = function () {
        Impl.callVoiceAPI("rel");
    };
    uni.initAD = function (gameID) {
        var url = "https://cdn.h5wan.4399sj.com/h5-ad-frame/dist/ad_api.js";
        var script = document.createElement("script");
        script.type = "text/javascript";
        script.src = url;
        document.getElementsByTagName("head")[0].appendChild(script);
        script.onload = function () {
            uni.ADApi = window["h5api"];
            if (uni.ADApi != undefined) {
                uni.ADApi["init"](gameID);
                uni.ADApi["onInited"] = function () {
                    if (uni.ADInitCallback != undefined) {
                        uni.ADInitCallback();
                    }
                };
                uni.ADApi["onPlayAd"] = function (state) {
                    console.log('代码:' + state["code"] + ',消息:' + state["message"]);
                    if (uni.ADPlayStateChangeCallback != null) {
                        uni.ADPlayStateChangeCallback(state);
                    }
                };
            }
            else {
                console.log("广告初始化失败，不存在window['h5api']对象");
            }
        };
        script.onerror = function () {
            console.log("广告js加载失败:" + url);
        };
    };
    /**
     * 是否可播放广告
     * @returns {boolean}
     * @constructor
     */
    uni.ADPlayable = function () {
        var able = false;
        if (uni.ADApi != null) {
            var data = uni.ADApi["canPlayAd"]();
            able = data["canPlayAd"];
        }
        return able;
    };
    uni.playAD = function () {
        if (uni.ADApi != null) {
            uni.ADApi["playAd"]();
        }
        else {
            console.error("playAD() 不存在window['h5api']对象");
        }
    };
    /**
     * 当前整体剩余广告可播放次数
     * @returns {number}
     * @constructor
     */
    uni.ADRemainTimes = function () {
        var times = 0;
        if (uni.ADApi != null) {
            var data = uni.ADApi["canPlayAd"]();
            times = data["remain"];
        }
        return times;
    };
    /**
     * 注册广告播放状态变更的回调
     * @param {(state:object)=>any} callback 回调函数，其中state包含两个属性{code:number, message:string}，code为10000代表开始播放，为10001代表播放结束，为其他值时代表播放异常
     */
    uni.onADPlayStateChange = function (callback) {
        uni.ADPlayStateChangeCallback = callback;
    };
    //<-////////////////////////////////////
    /**
     * 显示充值界面
     * @param {number} money 要充值的金额（RMB）
     * @param {string} mark 订单编号（由游戏方生成）
     * @param {string} ext 透传参数，充值通过后会将此参数加在充值回调接口地址后面
     */
    uni.displayPayDialog = function (money, mark, ext) {
        Impl.callGameAPI("openPay", uni.AppId, money, mark, ext);
    };
    uni.inited = false;
    uni.logined = false;
    //public static apiHost:string = "http://h5game.4399api.com:8080/service/gameApi/";
    //public static apiHost:string = "http://apiw0-xiuxian.aiwan4399.com:8080/service/gameApi/";
    uni.apiHost = "https://apiw0-xiuxian.aiwan4399.com/service/gameApi/";
    uni.apiHost_debug = "http://42.62.64.242:8080/service/gameApi/";
    //<-////////////////////////////////////////////
    uni.heartbeatTimeoutID = 0;
    uni.syncedLocalTime = 0;
    uni.syncedServerTime = 0;
    return uni;
}());
var Api = /** @class */ (function () {
    function Api() {
    }
    /**
     * 聊天框输入新消息
     */
    Api.inputMsg = function (msg) {
        Api.trace(msg);
        return true;
    };
    Api.didEnterBackground = function () {
        if (Api.didEnterBackgroundCallback != undefined) {
            Api.didEnterBackgroundCallback();
        }
    };
    Api.willEnterForeground = function () {
        if (Api.willEnterForegroundCallback != undefined) {
            Api.willEnterForegroundCallback();
        }
    };
    /**
     * 是否要弹出邀请界面
     */
    Api.getShowInvitation = function () {
        console.log("getShowInvitation() called");
        var flag = 0; //默认显示
        if (uni.inviteableCheckCallback != undefined) {
            flag = uni.inviteableCheckCallback() ? 0 : 1;
        }
        console.log("getShowInvitation() " + flag);
        Impl.callGameAPI("isShowInvitation", flag);
    };
    Api.onResume = function () {
    };
    /**
     * 在即将离开游戏时调用
     */
    Api.willLeaveGame = function () {
        Api.trace("willLeaveGame");
        uni.releaseVoiceChat();
        window.location.href = "about:blank";
    };
    /**
     * 初始化语音成功 回调 请在该方法回调后 调用setVoiceMode(String mode)
     */
    Api.voiceInitSuccess = function (code) {
        Api.trace("voiceInitSuccess:", code);
    };
    Api.onApplyMessageKeyError = function (code) {
        Api.trace("onApplyMessageKeyError:", code);
    };
    /**
     * 录音时间小于1秒回调
     */
    Api.micLessOneSec = function () {
        Api.trace("micLessOneSec");
    };
    /**
     * 当录音取消时回调 取消与停止是不一样的 调用停止录音 在本地会有该录音的缓存
     */
    Api.onCancelRecord = function () {
        Api.trace("onCancelRecord");
    };
    /**
     * 实时音量大小改变回调
     */
    Api.onMicLevelChange = function (level) {
        Api.trace("onMicLevelChange:", level);
    };
    /**
     * 当录音真正开始时回调
     */
    Api.onRecordStart = function () {
        Api.trace("onRecordStart");
    };
    /**
     * 当录音真正停止时回调
     */
    Api.onStopRecord = function (filePath) {
        Api.trace("onStopRecord", filePath);
    };
    /**
     * 播放语音错误 回调 -- 一般因为网络问题造成下载失败
     */
    Api.playVoiceError = function (fileId) {
        Api.trace("playVoiceError", fileId);
    };
    /**
     * 无录音权限回调
     */
    Api.unVoiceUnPermission = function () {
        Api.trace("unVoiceUnPermission");
    };
    /**
     * 录音上传成功时回调
     */
    Api.upLoadFileSuccess = function (fileID, time) {
        Api.trace("upLoadFileSuccess", fileID);
    };
    /**
     * 上传语音错误 回调
     */
    Api.uploadVoiceError = function (filePath) {
        Api.trace("uploadVoiceError", filePath);
    };
    /**
     * 游戏模块需要下载时，在下载完毕后app调用此接口
     */
    Api.onGameDownLoadSuccess = function () {
        Api.trace("游戏模块加载完成,app回调");
    };
    /**
     * 成功将邀请消息发到了app好友
     * @param {string} recipient_id
     * @param {string} recipient_name
     */
    Api.onSendInviteSuccess = function (recipient_id, recipient_name) {
        if (Api.inviteSendSuccessCallback != undefined) {
            Api.inviteSendSuccessCallback(recipient_id, recipient_name);
        }
    };
    Api.onInviteRefused = function (targetPID, targetName) {
        //console.log("Api.onInviteRefused() id:" + targetPID + " name:" + targetName);
        if (Api.inviteRefusedCallback != undefined) {
            Api.inviteRefusedCallback(targetPID, targetName);
        }
    };
    Api.onShareClick = function (msg) {
        Impl.onShareCallback(msg);
    };
    Api.trace = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        console.log(args);
    };
    return Api;
}());
var Impl = /** @class */ (function () {
    function Impl() {
    }
    Impl._init = function () {
        window["onGameProgress"] = function (progressValue) { };
        window["onGameDownLoadSuccess"] = function () { };
        Impl.callGameAPI("onFrameResReady", uni.AppId, 0);
    };
    Impl.startup = function () {
        var op = uni.urlVars["op"];
        //检查是否要创建游戏房间
        if (op == "app_create") {
            if (uni.createGameRoomCallback != undefined) {
                uni.createGameRoomCallback();
            }
        }
        //检查是否是被邀请进的游戏
        if (op == "invite") {
            var mixedJson = decodeURIComponent(uni.urlVars["id"]);
            var mixedPars = JSON.parse(mixedJson);
            //let uid = mixedPars["__uid__"];
            //let nickName = mixedPars["__nickName__"];
            //let parameters = mixedPars["parameters"];
            if (uni.startGameWithInvitationCallback != undefined) {
                uni.startGameWithInvitationCallback(mixedPars);
            }
        }
    };
    Impl.standby = function () {
        console.log("standby()");
        Impl.callGameAPI("onGameResReady");
        Impl.callGameAPI("onJsLoadComplete");
    };
    Impl.loginInPlatform = function (req, testSCookie, testPlatUID) {
        if (testSCookie === void 0) { testSCookie = null; }
        if (testPlatUID === void 0) { testPlatUID = null; }
        var scookie = Impl.callMainAPI("getSCookie") || testSCookie;
        var platUid = Impl.callMainAPI("getUserUid") || testPlatUID;
        var phoneType = Impl.callMainAPI("getClient");
        //*TEST:
        //phoneType = "IOS";
        ////////
        if (phoneType == "IOS") {
            phoneType = "ios";
            if (window.location.href.indexOf("http") == 0) {
                scookie = scookie.replace(/\|/g, "");
            }
        }
        else {
            phoneType = "android";
        }
        var url = uni.apiHost + "getGameInfo?loginType=1&scookie=" + scookie + "&uid=" + platUid + "&flag=" + uni.AppId + "&phoneType=" + phoneType;
        console.log("loginInPlatform() " + url);
        req.open("GET", url);
        req.send();
    };
    Impl.exit = function () {
        Impl.callMainAPI("finish");
    };
    /**
     * 获取APP版本
     */
    Impl.getAppVer = function () {
        return Impl.callMainAPI("getClientVer");
    };
    /**
     * 返回app类型:IOS、Android
     */
    Impl.getAppType = function () {
        return Impl.callMainAPI("getClient");
    };
    Impl.invite = function (parameters) {
        if (parameters === void 0) { parameters = null; }
        Impl.callGameAPI("openFriendListAndInvite", "invite", Impl.generateInvitePars(parameters), uni.AppId, uni.gameName, uni.gameType);
    };
    /*public static sendGameInvite(targetPUid: string, targetName: string): void {
        Impl.callMainAPI("sendGameInvite", targetPUid, targetName, "invite", Impl.pUid, uni.AppId, uni.gameName);
    }*/
    Impl.inviteFromSociety = function (parameters) {
        if (parameters === void 0) { parameters = null; }
        Impl.callGameAPI("showShareDialog", "invite", Impl.generateInvitePars(parameters), uni.AppId, uni.gameName, uni.gameType);
    };
    Impl.callMainAPI = function (apiName) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        var apiObj = window["mobileJs"];
        if (apiObj != null) {
            return apiObj[apiName].apply(apiObj, args);
        }
    };
    Impl.callGameAPI = function (apiName) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        var apiObj = window["gameJs"];
        if (apiObj != null) {
            var fun = apiObj[apiName];
            if (fun != null) {
                return fun.apply(apiObj, args);
            }
        }
    };
    Impl.callVoiceAPI = function (apiName) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        var apiObj = window["voiceChatJs"];
        if (apiObj != null) {
            return apiObj[apiName].apply(apiObj, args);
        }
    };
    Impl.generateInvitePars = function (parameters) {
        var obj = { uid: uni.uid, nickName: uni.nickName, parameters: parameters };
        return encodeURIComponent(JSON.stringify(obj));
    };
    Impl.setShareCallback = function (success, fail) {
        Impl.clearShareCallback();
        Impl.shareSuccessCallback = success;
        Impl.shareFailCallback = fail;
        if (Impl.shareFailCallback != undefined) {
            Impl.shareCallbackTimerID = setTimeout(Impl.onShareTimeout, 50000);
        }
    };
    Impl.onShareCallback = function (msg) {
        var fn = Impl.shareSuccessCallback;
        Impl.clearShareCallback();
        if (fn != undefined) {
            fn(msg);
        }
    };
    Impl.onShareTimeout = function () {
        var fn = Impl.shareFailCallback;
        Impl.clearShareCallback();
        if (fn != undefined) {
            fn();
        }
    };
    Impl.clearShareCallback = function () {
        Impl.shareSuccessCallback = null;
        Impl.shareFailCallback = null;
        if (Impl.shareCallbackTimerID > 0) {
            clearTimeout(Impl.shareCallbackTimerID);
            Impl.shareCallbackTimerID = 0;
        }
    };
    Impl.shareCallbackTimerID = 0;
    return Impl;
}());
var Open4399Impl = /** @class */ (function () {
    function Open4399Impl() {
    }
    Open4399Impl.markWaitToLogin = function (argsOfLogin) {
        Open4399Impl.argsOfLogin = argsOfLogin;
        Open4399Impl.waitToLogin = true;
    };
    Open4399Impl.createApiRef = function () {
        var script = document.createElement("script");
        script.type = "text/javascript";
        script.src = "https://cdn.h5wan.4399sj.com/h5web-frame/dist/static/js/api.js";
        document.getElementsByTagName("head")[0].appendChild(script);
        script.onload = function () {
            Open4399Impl.APIRefCreated = true;
            Open4399Impl.api = window["H5API"];
            if (Open4399Impl.waitToLogin) {
                uni.login(Open4399Impl.argsOfLogin);
                Open4399Impl.waitToLogin = false;
                Open4399Impl.argsOfLogin = null;
            }
        };
    };
    Open4399Impl.startup = function () {
        Open4399Impl.createApiRef();
        var startUpVariables = Open4399Impl.decodePars(uni.urlVars["extra"]);
        var op = startUpVariables["op"];
        //检查是否是被邀请进的游戏
        if (op == "invite") {
            var mixedJson = decodeURIComponent(startUpVariables["parameters"]);
            var mixedPars = JSON.parse(mixedJson);
            if (uni.startGameWithInvitationCallback != undefined) {
                uni.startGameWithInvitationCallback(mixedPars);
            }
        }
    };
    Open4399Impl.loginInPlatform = function (req) {
        var flag = uni.urlVars["flag"];
        var account = decodeURIComponent(uni.urlVars["account"]);
        var gameId = uni.urlVars["gameId"];
        var nick = decodeURIComponent(uni.urlVars["nick"]);
        var userId = uni.urlVars["userId"];
        var userName = decodeURIComponent(uni.urlVars["userName"]);
        var time = uni.urlVars["time"];
        var sign = uni.urlVars["sign"];
        var url = uni.apiHost + "getGameInfo?loginType=2&phoneType=android";
        url += "&flag=" + flag;
        url += "&account=" + account;
        url += "&gameId=" + gameId;
        url += "&nick=" + nick;
        url += "&userId=" + userId;
        url += "&userName=" + userName;
        url += "&time=" + time;
        url += "&sign=" + sign;
        req.open("GET", url);
        req.send();
    };
    /**
     * app好友邀请
     * @param {object} parameters
     */
    Open4399Impl.invite = function (parameters) {
        var extra = Open4399Impl.encodePars({ parameters: parameters, op: "invite" });
        Open4399Impl.api.appShare(extra);
    };
    Open4399Impl.inviteFromSociety = function (parameters) {
        var extra = Open4399Impl.encodePars({ parameters: parameters, op: "invite" });
        Open4399Impl.api.shareGame(extra);
    };
    Open4399Impl.viewUserProfile = function (uid) {
        Open4399Impl.api.openUserCenter(uid);
    };
    /**
     * 获取用户头像地址
     */
    Open4399Impl.getUserAvatar = function (uid) {
        return Open4399Impl.api.getUserAvatar(uid);
    };
    Open4399Impl.encodePars = function (obj) {
        var sep = "_sep_";
        var str = "";
        for (var key in obj) {
            str += key + sep + obj[key] + sep;
        }
        if (str.length > 0) {
            str = str.substr(0, str.length - 7);
        }
        return str;
    };
    Open4399Impl.decodePars = function (str) {
        var sep = "_sep_";
        var arr = str.split(sep);
        var obj = {};
        for (var i = 0; i < arr.length; i++) {
            obj[arr[i]] = arr[i + 1];
            console.log(arr[i] + ":" + arr[i + 1]);
            i++;
        }
        return obj;
    };
    Open4399Impl.waitToLogin = false;
    //4399原创API是否已经准备完毕
    Open4399Impl.APIRefCreated = false;
    return Open4399Impl;
}());
var UniPlat;
(function (UniPlat) {
    UniPlat[UniPlat["ZQ"] = 0] = "ZQ";
    UniPlat[UniPlat["OPEN43"] = 1] = "OPEN43";
})(UniPlat || (UniPlat = {}));
//游戏类型 1:双人游戏, 2:多人游戏, 3:单人游戏
var UniGameType;
(function (UniGameType) {
    UniGameType[UniGameType["TWO_PLAYER"] = 1] = "TWO_PLAYER";
    UniGameType[UniGameType["MULTIPLAYER"] = 2] = "MULTIPLAYER";
    UniGameType[UniGameType["SINGLE_PLAYER"] = 3] = "SINGLE_PLAYER";
})(UniGameType || (UniGameType = {}));
uni._init();
window["Api"] = Api;
window["onResume"] = function () { };
